%% Code to reproduce figures 3-5.

% First section: obtain IC for differet value of k and c
restrfact=5;
rng('default') % Reinitialize the random number generator to its startup configuration
rng(20000);
ktrue=3;
% n = number of observations
n=150;
% v= number of dimensions
v=2;
% Imposed average overlap
BarOmega=0.04;

out=MixSim(ktrue,v,'BarOmega',BarOmega, 'restrfactor',restrfact);
% data generation given centroids and cov matrices
[Y,id]=simdataset(n, out.Pi, out.Mu, out.S);

nsamp=20000;

% Computation of information criterion
out=tclustIC(Y,'cleanpool',false,'plots',0,'nsamp',nsamp); % ,'numpool',1);

%%
prin=0;

% Set figure3=0 to obtain figure 4
figure3=1;


if figure3==1
    stri='clacla';
    X=out.CLACLA;
else
    stri='mixmix';
    X=out.MIXMIX;
end

maxk=5;
% MIXMIX
simj=1;
cc=[1 2 4 8 16 32 64 128];
ticklab={'c=1' 'c=2', 'c=4', 'c=8', 'c=16', ...
    'c=32' 'c=64' 'c=128'};

LinStyle={'-','--',':','-.','-','--',':','-.'};
Marker={'o','+','*','x','s','d','^','h'};
Color={'r','b','k','m','r','b','k','m'};
lwd=1.2;

subplot(3,3,[1 4 7])
hold('on')
for j=1:8
    plot((1:maxk)',X(:,j,simj),'LineWidth',lwd,'LineStyle',LinStyle{j},'Marker',Marker{j},'Color',Color{j})
end
xlabel('k','FontSize',14)
legend('show','String',ticklab,'FontSize',12,'Location','northwest')
xlim([1 5])

FontSize=14;

minminy=min(min(X));
maxmaxy=minminy+50;
ylim([minminy maxmaxy])
sel=[2 3 5 6 8];
for j=1:5
    subplot(3,3,sel(j))
    plot((1:maxk)',X(:,j,simj),'LineWidth',lwd,'LineStyle',LinStyle{j},'Marker',Marker{j},'Color',Color{j})
    title(ticklab(j),'FontSize',FontSize)
    if j>0
        ylim([minminy maxmaxy])
    end
    xlim([1 5])
end
xlabel('k','FontSize',14)

subplot(3,3,9)
hold('on')
for j=6:8
    plot((1:maxk)',X(:,j,simj),'LineWidth',lwd,'LineStyle',LinStyle{j},'Marker',Marker{j},'Color',Color{j})
end
box('on')
title('c=[32, 64, 128]','FontSize',FontSize)
xlabel('k','FontSize',14)

ylim([minminy maxmaxy])

xlim([1 5])
printstring=['print -depsc latex\' stri 'BIC.eps'];

if prin==1
    % print to postscript
    eval(printstring)
end


%% Contour plot all 3 sol
close all
newlabel={'2^0' '2^1' '2^2' '2^3' '2^4' '2^5' '2^6' '2^7'};
X=out.MIXMIX;
subplot(1,3,1)
contour(X,10,'ShowText','on')
xlim([1 length(cc)])
set(gca,'Xticklabel',newlabel)
xlabel('Restriction factor c')
ylim([1 maxk])
set(gca,'YTick',1:maxk)
ylabel('Number of groups k')
title('MIXMIX')

subplot(1,3,2)
X=out.MIXCLA;
contour(X,10,'ShowText','on')
xlim([1 length(cc)])
set(gca,'Xticklabel',newlabel)
xlabel('Restriction factor c')
ylim([1 maxk])
set(gca,'YTick',1:maxk)
% ylabel('Number of groups k')
title('MIXCLA')

subplot(1,3,3)
X=out.CLACLA;
contour(X,10,'ShowText','on')
xlim([1 length(cc)])
set(gca,'Xticklabel',newlabel)
xlabel('Restriction factor c')
ylim([1 maxk])
set(gca,'YTick',1:maxk)
% ylabel('Number of groups k')
title('CLACLA')
if prin==1
    % print to postscript
    print -depsc latex\figs\contour.eps
end
